@@ -84,7 +84,8 @@ QStringList AppPackageKitResource::mimetypes() const
 QStringList AppPackageKitResource::categories()
 {
     auto cats = m_appdata.categories();
-    cats.append(QStringLiteral("Application"));
+    if (m_appdata.kind() != Appstream::Component::KindAddon)
+        cats.append(QStringLiteral("Application"));
     return cats;
 }
 
@@ -104,8 +105,7 @@ QString AppPackageKitResource::appstreamId() const
 
 QUrl AppPackageKitResource::homepage()
 {
-    QList< QUrl > urls = m_appdata.urls(Appstream::Component::UrlKindHomepage);
-    return urls.isEmpty() ? PackageKitResource::homepage() : urls.first();
+    return m_appdata.urls().value(Appstream::Component::UrlKindHomepage);
 }
 
 bool AppPackageKitResource::isTechnical() const
