@@ -56,7 +56,7 @@ PackageKitBackend::PackageKitBackend(QObject* parent)
 {
     bool b = m_appdata.open();
     if (!b) {
-        qWarning() << "Couldn't open the AppStream database";
+        qWarning() << "Could not open the AppStream metadata pool";
 
         auto msg = new QAction(i18n("Got it"), this);
         msg->setWhatsThis(i18n("Please make sure that Appstream is properly set up on your system"));
@@ -72,6 +72,10 @@ PackageKitBackend::PackageKitBackend(QObject* parent)
     t->setSingleShot(false);
     t->start();
 
+    m_delayedDetailsFetch.setSingleShot(true);
+    m_delayedDetailsFetch.setInterval(0);
+    connect(&m_delayedDetailsFetch, &QTimer::timeout, this, &PackageKitBackend::performDetailsFetch);
+
     QAction* updateAction = new QAction(this);
     updateAction->setIcon(QIcon::fromTheme(QStringLiteral("system-software-update")));
     updateAction->setText(i18nc("@action Checks the Internet for updates", "Check for Updates"));
@@ -177,6 +181,14 @@ class TransactionSet : public QObject
 
 };
 
+void PackageKitBackend::clearPackages(const QStringList& packageNames)
+{
+    const auto resources = resourcesByPackageNames<QVector<AbstractResource*>>(packageNames);
+    for(auto res: resources) {
+        qobject_cast<PackageKitResource*>(res)->clearPackageIds();
+    }
+}
+
 void PackageKitBackend::resolvePackages(const QStringList &packageNames)
 {
     PackageKit::Transaction * tArch = PackageKit::Daemon::resolve(packageNames, PackageKit::Transaction::FilterArch);
@@ -463,6 +475,23 @@ QString PackageKitBackend::upgradeablePackageId(const PackageKitResource* res) c
     return QString();
 }
 
+void PackageKitBackend::fetchDetails(const QString& pkgid)
+{
+    if (!m_delayedDetailsFetch.isActive()) {
+        m_delayedDetailsFetch.start();
+    }
+
+    m_packageNamesToFetchDetails += pkgid;
+}
+
+void PackageKitBackend::performDetailsFetch()
+{
+    Q_ASSERT(!m_packageNamesToFetchDetails.isEmpty());
+    PackageKit::Transaction* transaction = PackageKit::Daemon::getDetails(m_packageNamesToFetchDetails.toList());
+    connect(transaction, &PackageKit::Transaction::details, this, &PackageKitBackend::packageDetails);
+    connect(transaction, &PackageKit::Transaction::errorCode, this, &PackageKitBackend::transactionError);
+}
+
 void PackageKitBackend::checkDaemonRunning()
 {
     if (!PackageKit::Daemon::isRunning()) {
