@@ -25,7 +25,8 @@
 #include <resources/AbstractResourcesBackend.h>
 #include <QVariantList>
 #include <QStringList>
-#include <qpointer.h>
+#include <QPointer>
+#include <QTimer>
 #include <QSet>
 #include <PackageKit/Transaction>
 #include <AppstreamQt/database.h>
@@ -63,7 +64,9 @@ class DISCOVERCOMMON_EXPORT PackageKitBackend : public AbstractResourcesBackend
         QVector<AppPackageKitResource*> extendedBy(const QString& id) const;
         void fetchUpdates();
 
+        void clearPackages(const QStringList &packageNames);
         void resolvePackages(const QStringList &packageNames);
+        void fetchDetails(const QString& pkgid);
 
     public Q_SLOTS:
         void transactionCanceled(Transaction* t);
@@ -91,6 +94,7 @@ class DISCOVERCOMMON_EXPORT PackageKitBackend : public AbstractResourcesBackend
         void checkDaemonRunning();
         void acquireFetching(bool f);
         void includePackagesToAdd();
+        void performDetailsFetch();
 
         Appstream::Database m_appdata;
         QList<Transaction*> m_transactions;
@@ -109,6 +113,8 @@ class DISCOVERCOMMON_EXPORT PackageKitBackend : public AbstractResourcesBackend
             void clear() { *this = {}; }
         };
 
+        QTimer m_delayedDetailsFetch;
+        QSet<QString> m_packageNamesToFetchDetails;
         Packages m_packages;
         AppstreamReviews* const m_reviews;
 };
